# UofG-Timetable-CLI

Retrieve your UofG Timetable via CLI!

Features:
- Supports persistant sessions (you don't have to login multiple times)
- Supports different timezones (Converts all event times into your login timezone)
- Supports retrieving timetable for multiple days!

TODO:
- Add support for more timezones (currently supports Asia/Kolkata)
- Add some colors in the output?
